@@ -1,5 +1,5 @@
 """Various Settings templates used throughout QMFlows."""
 
-from .templates import (freq, geometry, singlepoint, ts, md, cell_opt)
+from ._templates import (freq, geometry, singlepoint, ts, md, cell_opt)
 
 __all__ = ['freq', 'geometry', 'singlepoint', 'ts', 'md', 'cell_opt']
