@@ -14,6 +14,7 @@ Index
     requires_orca
     requires_ams
     requires_adf
+    find_executable
 
 API
 ---
@@ -30,17 +31,21 @@ API
 .. autodata:: requires_orca
 .. autodata:: requires_ams
 .. autodata:: requires_adf
+.. autofunction:: find_executable
+.. autodata:: stdout_to_logger
 
 """
 
 import os
+import sys
 import textwrap
+import logging
+import contextlib
 from pathlib import Path
 
 import pytest
-from distutils.spawn import find_executable
 
-from .settings import Settings
+from . import logger, Settings
 from .warnings_qmflows import Assertion_Warning
 from .packages import Result
 
@@ -55,6 +60,8 @@ __all__ = [
     'requires_orca'
     'requires_ams',
     'requires_adf',
+    'find_executable',
+    'stdout_to_logger',
 ]
 
 try:
@@ -73,6 +80,49 @@ PATH = Path('test') / 'test_files'
 PATH_MOLECULES = PATH / "molecules"
 
 
+def find_executable(executable: str, path: "str | None" = None) -> "str | None":
+    """Tries to find ``executable`` in the directories listed in ``path``.
+
+    A string listing directories separated by ``os.pathsep``; defaults to ``os.environ['PATH']``.
+    Returns the complete filename or ``None`` if not found.
+
+    Note
+    ----
+    Vendored copy of :func:`distutils.spawn.find_executable`,
+    as the entirety of distutils is deprecated per PEP 632.
+
+    """
+    _, ext = os.path.splitext(executable)
+    if (sys.platform == 'win32') and (ext != '.exe'):
+        executable = executable + '.exe'
+
+    if os.path.isfile(executable):
+        return executable
+
+    if path is None:
+        path = os.environ.get('PATH', None)
+        if path is None:
+            try:
+                path = os.confstr("CS_PATH")
+            except (AttributeError, ValueError):
+                # os.confstr() or CS_PATH is not available
+                path = os.defpath
+        # bpo-35755: Don't use os.defpath if the PATH environment variable is
+        # set to an empty string
+
+    # PATH='' doesn't match, whereas PATH=':' looks in the current directory
+    if not path:
+        return None
+
+    paths = path.split(os.pathsep)
+    for p in paths:
+        f = os.path.join(p, executable)
+        if os.path.isfile(f):
+            # the file exists, we have a shot at spawn working
+            return f
+    return None
+
+
 def fill_cp2k_defaults(s: Settings) -> Settings:
     """Fill missing values from a job template.
 
@@ -215,3 +265,37 @@ requires_adf = pytest.mark.skipif(
     not _has_env_vars("ADFBIN", "ADFHOME", "ADFRESOURCES"),
     reason="Requires ADF <=2019",
 )
+
+
+class _StdOutToLogger(contextlib.redirect_stdout, contextlib.ContextDecorator):
+    """A context decorator and file-like object for redirecting the stdout stream to a logger.
+
+    Attributes
+    ----------
+    logger : logging.Logger
+        The wrapped logger.
+    level : int
+        The logging level.
+
+    """
+
+    __slots__ = ("logger", "level")
+
+    def __init__(self, logger: logging.Logger, level: int = logging.INFO) -> None:
+        super().__init__(self)
+        self.logger = logger
+        self.level = level
+
+    def write(self, msg: str) -> None:
+        """Log '`msg'` with the integer severity :attr:`level`."""
+        self.logger.log(self.level, msg)
+
+    def flush(self) -> None:
+        """Ensure aqll logging output has been flushed."""
+        for handler in self.logger.handlers:
+            handler.flush()
+
+
+#: A context decorator and file-like object for redirecting the stdout
+#: stream to the qmflows logger.
+stdout_to_logger = _StdOutToLogger(logger)
